In the curated case, the returned data frame has columns 'date', 'source' which are the main
useful fields, these describe the date of the data in the file, and its full URI (Uniform Resource Identifier) source on
S3 object storage. There are also fields 'Bucket', 'Key', and 'protocol' from which 'source' is
constructed.
The original publisher URI can be reconstructed by replacing the value of 'protocol' in 'source'
with 'https://'.
The public object URI can be reconstructed by replacing the value of 'protocol' in 'source' with
'https://projects.pawsey.org.au'.